@@ -24,9 +24,9 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 
-from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import (QButtonGroup, QFileDialog, QGridLayout, QLineEdit,
-        QRadioButton, QVBoxLayout, QWidget)
+from PyQt5.QtCore import pyqtSignal, Qt
+from PyQt5.QtWidgets import (QButtonGroup, QCheckBox, QFileDialog, QGridLayout,
+        QGroupBox, QLineEdit, QRadioButton, QVBoxLayout, QWidget)
 
 from .better_form import BetterForm
 from .filename_editor import FilenameEditor
@@ -70,38 +70,67 @@ class ApplicationPage(QWidget):
 
         form = BetterForm()
 
+        self._name_edit = QLineEdit(
+                placeholderText="Application name",
+                whatsThis="The name of the application. It will default to "
+                        "the base name of the application script without any "
+                        "extension.",
+                textEdited=self._name_changed)
+        form.addRow("Name", self._name_edit)
+
         self._script_edit = FilenameEditor("Application Script",
                 placeholderText="Application script",
-                whatsThis="The name of the application's main script file.",
+                whatsThis="The name of the application's optional main script "
+                        "file.",
                 textEdited=self._script_changed)
         form.addRow("Main script file", self._script_edit)
 
+        self._entry_point_edit = QLineEdit(
+                placeholderText="Entry point in application package",
+                whatsThis="The name of the optional entry point in the "
+                        "application's package.",
+                textEdited=self._entry_point_changed)
+        form.addRow("Entry point", self._entry_point_edit)
+
         self._sys_path_edit = QLineEdit(
                 placeholderText="Additional sys.path directories",
                 whatsThis="A space separated list of additional directories "
-                        "to add to <tt>sys.path</tt>.  Only set this if you "
+                        "to add to <tt>sys.path</tt>. Only set this if you "
                         "want to allow external packages to be imported.",
                 textEdited=self._sys_path_changed)
         form.addRow("sys.path", self._sys_path_edit)
 
         layout.addLayout(form, 0, 0)
 
-        versions_layout = QVBoxLayout()
+        options_layout = QVBoxLayout()
         self._pyqt_versions_bg = QButtonGroup()
 
         for version in ('PyQt5', 'PyQt4'):
             rb = QRadioButton(version)
-            versions_layout.addWidget(rb)
+            options_layout.addWidget(rb)
             self._pyqt_versions_bg.addButton(rb)
 
         self._pyqt_versions_bg.buttonToggled.connect(
                 self._pyqt_version_changed)
 
-        layout.addLayout(versions_layout, 0, 1)
+        self._console_edit = QCheckBox("Use console (Windows)",
+                stateChanged=self._console_changed)
+        options_layout.addWidget(self._console_edit)
+
+        self._bundle_edit = QCheckBox("Application bundle (OS/X)",
+                stateChanged=self._bundle_changed)
+        options_layout.addWidget(self._bundle_edit)
+
+        options_layout.addStretch()
+
+        layout.addLayout(options_layout, 0, 1)
 
         self._package_edit = _ApplicationPackageEditor()
         self._package_edit.package_changed.connect(self._package_changed)
-        layout.addWidget(self._package_edit, 1, 0, 1, 2)
+        package_edit_gb = QGroupBox(self._package_edit.title)
+        package_edit_gb.setLayout(self._package_edit)
+        layout.addWidget(package_edit_gb, 1, 0, 1, 2)
+        layout.setRowStretch(1, 1)
 
         self.setLayout(layout)
 
@@ -110,11 +139,13 @@ class ApplicationPage(QWidget):
 
         project = self.project
 
+        self._name_edit.setText(project.application_name)
         self._script_edit.setText(project.application_script)
+        self._entry_point_edit.setText(project.application_entry_point)
         self._sys_path_edit.setText(project.sys_path)
         self._package_edit.configure(project.application_package, project)
 
-        self._pyqt_versions_bg.blockSignals(True)
+        blocked = self._pyqt_versions_bg.blockSignals(True)
 
         for rb in self._pyqt_versions_bg.buttons():
             if rb.text() == 'PyQt5':
@@ -122,7 +153,17 @@ class ApplicationPage(QWidget):
             else:
                 rb.setChecked(not project.application_is_pyqt5)
 
-        self._pyqt_versions_bg.blockSignals(False)
+        self._pyqt_versions_bg.blockSignals(blocked)
+
+        blocked = self._console_edit.blockSignals(True)
+        self._console_edit.setCheckState(
+                Qt.Checked if project.application_is_console else Qt.Unchecked)
+        self._console_edit.blockSignals(blocked)
+
+        blocked = self._bundle_edit.blockSignals(True)
+        self._bundle_edit.setCheckState(
+                Qt.Checked if project.application_is_bundle else Qt.Unchecked)
+        self._bundle_edit.blockSignals(blocked)
 
     def _pyqt_version_changed(self, button, checked):
         """ Invoked when the user changes the PyQt version number. """
@@ -133,12 +174,36 @@ class ApplicationPage(QWidget):
 
             self.pyqt_version_changed.emit(checked)
 
+    def _console_changed(self, state):
+        """ Invoked when the user changes the console state. """
+
+        self.project.application_is_console = (state == Qt.Checked)
+        self.project.modified = True
+
+    def _bundle_changed(self, state):
+        """ Invoked when the user changes the bundle state. """
+
+        self.project.application_is_bundle = (state == Qt.Checked)
+        self.project.modified = True
+
+    def _name_changed(self, value):
+        """ Invoked when the user edits the application name. """
+
+        self.project.application_name = value
+        self.project.modified = True
+
     def _script_changed(self, value):
         """ Invoked when the user edits the application script name. """
 
         self.project.application_script = value
         self.project.modified = True
 
+    def _entry_point_changed(self, value):
+        """ Invoked when the user edits the entry point. """
+
+        self.project.application_entry_point = value
+        self.project.modified = True
+
     def _sys_path_changed(self, value):
         """ Invoked when the user edits the sys.path directories. """
 
@@ -155,12 +220,12 @@ class _ApplicationPackageEditor(QrcPackageEditor):
     """ A memory filesystem package editor for the application package. """
 
     # The editor title.
-    _title = "Application Package"
+    title = "Application Package Directory"
 
     def __init__(self):
         """ Initialise the editor. """
 
-        super().__init__(self._title, show_root=True, scan="Scan...")
+        super().__init__(show_root=True, scan="Scan...")
 
         self._project = None
 
@@ -172,12 +237,13 @@ class _ApplicationPackageEditor(QrcPackageEditor):
 
         orig = default = application_package.name
         if default != '':
-            default = project.absolute_path(default)
+            default = project.path_from_user(default)
 
-        root = QFileDialog.getExistingDirectory(self, self._title, default)
+        root = QFileDialog.getExistingDirectory(self.parentWidget(),
+                self.title, default)
 
         if root != '':
-            application_package.name = project.relative_path(root)
+            application_package.name = project.path_to_user(root)
 
         return root
 
