@@ -24,10 +24,10 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 
-from .metadata import Metadata
+from .pyqt_metadata import PyQtMetadata
 
 
-class PyQt5Metadata(Metadata):
+class PyQt5Metadata(PyQtMetadata):
     """ Encapsulate the meta-data for a single PyQt5 module. """
 
     def __init__(self, group='base', deps=(), gui=True, qt5=(), config5=()):
@@ -158,6 +158,11 @@ pyqt5_metadata = {
                                     gui=False,
                                     qt5=['xmlpatterns', 'network']),
 
+    'Enginio':                  PyQt5Metadata(
+                                    deps=['QtNetwork'],
+                                    gui=False,
+                                    qt5=['enginio']),
+
     'uic':                      PyQt5Metadata(
                                     deps=['QtWidgets']),
 
@@ -179,6 +184,11 @@ pyqt5_metadata = {
                                     deps=['QtGui'],
                                     qt5=['datavisualization']),
 
+    'QtPurchasing':             PyQt5Metadata(
+                                    group='addon',
+                                    deps=['QtCore'],
+                                    qt5=['purchasing']),
+
     'Qsci':                     PyQt5Metadata(
                                     group='addon',
                                     deps=['QtWidgets'],
