@@ -255,7 +255,7 @@ pyconfig = (
     Config('HAVE_EPOLL', android=1, linux=1),
 
     # Define if you have the 'epoll_create1' function.
-    Config('HAVE_EPOLL_CREATE1', android=1, linux=1),
+    Config('HAVE_EPOLL_CREATE1', linux=1),
 
     # Define to 1 if you have the `erf' function.
     Config('HAVE_ERF', default=1),
@@ -581,7 +581,7 @@ pyconfig = (
     Config('HAVE_LOG1P', default=1),
 
     # Define to 1 if you have the `log2' function.
-    Config('HAVE_LOG2', default=1),
+    Config('HAVE_LOG2', default=1, android=None),
 
     # Define this if you have the type long double.
     Config('HAVE_LONG_DOUBLE', default=1),
